@@ -51,10 +51,10 @@
 #endif /* PTHREADS */
 
 /* locally defined functions */
-static ptr new_open_output_fd_helper PROTO((const char *filename, INT mode,
+static ptr new_open_output_fd_helper(const char *filename, INT mode,
              INT flags, INT no_create, INT no_fail, INT no_truncate,
-             INT append, INT lock, INT replace, INT compressed));
-static INT lockfile PROTO((INT fd));
+             INT append, INT lock, INT replace, INT compressed);
+static INT lockfile(INT fd);
 static int is_valid_zlib_length(iptr count);
 static int is_valid_lz4_length(iptr count);
 
@@ -453,6 +453,27 @@ ptr S_bytevector_read(ptr file, ptr bv, iptr start, iptr count, IBOOL gzflag) {
 #endif
 
   LOCKandDEACTIVATE(tc, bv)
+#ifdef CHECK_FOR_ROSETTA
+  /* If we are running on Apple Silicon under Rosetta 2 translation, work around
+     a bug (present in 11.2.3 at least) in its handling of memory page protection
+     bits.  One of the tasks that Rosetta handles is to appropriately twiddle the
+     execute and write bits based on what's happinging to the memory in order to
+     preserve the illusion that the pages have RWX permissions, whereas Apple
+     Silicon enforces a W^X (write XOR execute) model.  For some reason, this
+     bit-twiddling sometimes fails when the bytevector passed to `read` extends
+     onto a page that's currently R-X, causing the `read` to fail with EFAULT
+     ("bad address").  By writing to each subsequent page, we force Rosetta to
+     do the right magic to the protection bits.  (Or at least it makes the error
+     go away and all the mats pass.)
+     */
+  if (is_rosetta) {
+    for (iptr idx = start+count; idx > start; idx -= S_pagesize) {
+      volatile octet b = BVIT(bv,idx);
+      BVIT(bv,idx) = b;
+    }
+  }
+#endif
+
 #ifdef WIN32
   if (!gzflag && fd == 0 && hStdin != NULL) {
     DWORD error_code;
@@ -796,7 +817,7 @@ ptr S_set_fd_length(ptr file, ptr length, IBOOL gzflag) {
   return flag ? S_strerror(errno) : Strue;
 }
 
-void S_new_io_init() {
+void S_new_io_init(void) {
   if (S_boot_time) {
     S_set_symbol_value(S_intern((const unsigned char *)"$c-bufsiz"), Sinteger(SBUFSIZ));
   }
