@@ -21,102 +21,102 @@
 #include <sys/stat.h>
 #include <limits.h>
 #include <ctype.h>
-#include <time.h>
+#include <math.h>
 
 /* locally defined functions */
-static INT s_errno PROTO((void));
-static iptr s_addr_in_heap PROTO((uptr x));
-static iptr s_ptr_in_heap PROTO((ptr x));
-static ptr s_generation PROTO((ptr x));
-static iptr s_fxmul PROTO((iptr x, iptr y));
-static iptr s_fxdiv PROTO((iptr x, iptr y));
-static ptr s_trunc_rem PROTO((ptr x, ptr y));
-static ptr s_fltofx PROTO((ptr x));
-static ptr s_weak_pairp PROTO((ptr p));
-static ptr s_ephemeron_cons PROTO((ptr car, ptr cdr));
-static ptr s_ephemeron_pairp PROTO((ptr p));
-static ptr s_oblist PROTO((void));
-static ptr s_bigoddp PROTO((ptr n));
-static ptr s_float PROTO((ptr x));
-static ptr s_decode_float PROTO((ptr x));
+static INT s_errno(void);
+static iptr s_addr_in_heap(uptr x);
+static iptr s_ptr_in_heap(ptr x);
+static ptr s_generation(ptr x);
+static iptr s_fxmul(iptr x, iptr y);
+static iptr s_fxdiv(iptr x, iptr y);
+static ptr s_trunc_rem(ptr x, ptr y);
+static ptr s_fltofx(ptr x);
+static ptr s_weak_pairp(ptr p);
+static ptr s_ephemeron_cons(ptr car, ptr cdr);
+static ptr s_ephemeron_pairp(ptr p);
+static ptr s_oblist(void);
+static ptr s_bigoddp(ptr n);
+static ptr s_float(ptr x);
+static ptr s_decode_float(ptr x);
 #ifdef segment_t2_bits
-static void s_show_info PROTO((FILE *out));
+static void s_show_info(FILE *out);
 #endif
-static void s_show_chunks PROTO((FILE *out, ptr sorted_chunks));
-static ptr sort_chunks PROTO((ptr ls, uptr n));
-static ptr merge_chunks PROTO((ptr ls1, ptr ls2));
-static ptr sorted_chunk_list PROTO((void));
-static void s_showalloc PROTO((IBOOL show_dump, const char *outfn));
-static ptr s_system PROTO((const char *s));
-static ptr s_process PROTO((char *s, IBOOL stderrp));
-static I32 s_chdir PROTO((const char *inpath));
-static char *s_getwd PROTO((void));
-static ptr s_set_code_byte PROTO((ptr p, ptr n, ptr x));
-static ptr s_set_code_word PROTO((ptr p, ptr n, ptr x));
-static ptr s_set_code_long PROTO((ptr p, ptr n, ptr x));
-static void s_set_code_long2 PROTO((ptr p, ptr n, ptr h, ptr l));
-static ptr s_set_code_quad PROTO((ptr p, ptr n, ptr x));
-static ptr s_set_reloc PROTO((ptr p, ptr n, ptr e));
-static ptr s_flush_instruction_cache PROTO((void));
-static ptr s_make_code PROTO((iptr flags, iptr free, ptr name, ptr arity_mark, iptr n, ptr info, ptr pinfos));
-static ptr s_make_reloc_table PROTO((ptr codeobj, ptr n));
-static ptr s_make_closure PROTO((ptr offset, ptr codeobj));
-static ptr s_fxrandom PROTO((ptr n));
-static ptr s_flrandom PROTO((ptr x));
-static U32 s_random_seed PROTO((void));
-static void s_set_random_seed PROTO((U32 x));
-static ptr s_intern PROTO((ptr x));
-static ptr s_intern2 PROTO((ptr x, ptr n));
-static ptr s_strings_to_gensym PROTO((ptr pname_str, ptr uname_str));
-static ptr s_intern3 PROTO((ptr x, ptr n, ptr m));
-static ptr s_delete_file PROTO((const char *inpath));
-static ptr s_delete_directory PROTO((const char *inpath));
-static ptr s_rename_file PROTO((const char *inpath1, const char *inpath2));
-static ptr s_mkdir PROTO((const char *inpath, INT mode));
-static ptr s_chmod PROTO((const char *inpath, INT mode));
-static ptr s_getmod PROTO((const char *inpath, IBOOL followp));
-static ptr s_path_atime PROTO((const char *inpath, IBOOL followp));
-static ptr s_path_ctime PROTO((const char *inpath, IBOOL followp));
-static ptr s_path_mtime PROTO((const char *inpath, IBOOL followp));
-static ptr s_fd_atime PROTO((INT fd));
-static ptr s_fd_ctime PROTO((INT fd));
-static ptr s_fd_mtime PROTO((INT fd));
-static IBOOL s_fd_regularp PROTO((INT fd));
-static void s_nanosleep PROTO((ptr sec, ptr nsec));
-static ptr s_set_collect_trip_bytes PROTO((ptr n));
-static void c_exit PROTO((I32 status));
-static ptr s_get_reloc PROTO((ptr co));
+static void s_show_chunks(FILE *out, ptr sorted_chunks);
+static ptr sort_chunks(ptr ls, uptr n);
+static ptr merge_chunks(ptr ls1, ptr ls2);
+static ptr sorted_chunk_list(void);
+static void s_showalloc(IBOOL show_dump, const char *outfn);
+static ptr s_system(const char *s);
+static ptr s_process(char *s, IBOOL stderrp);
+static I32 s_chdir(const char *inpath);
+static char *s_getwd(void);
+static ptr s_set_code_byte(ptr p, ptr n, ptr x);
+static ptr s_set_code_word(ptr p, ptr n, ptr x);
+static ptr s_set_code_long(ptr p, ptr n, ptr x);
+static void s_set_code_long2(ptr p, ptr n, ptr h, ptr l);
+static ptr s_set_code_quad(ptr p, ptr n, ptr x);
+static ptr s_set_reloc(ptr p, ptr n, ptr e);
+static ptr s_flush_instruction_cache(void);
+static ptr s_make_code(iptr flags, iptr free, ptr name, ptr arity_mark, iptr n, ptr info, ptr pinfos);
+static ptr s_make_reloc_table(ptr codeobj, ptr n);
+static ptr s_make_closure(ptr offset, ptr codeobj);
+static ptr s_fxrandom(ptr n);
+static ptr s_flrandom(ptr x);
+static U32 s_random_seed(void);
+static void s_set_random_seed(U32 x);
+static ptr s_intern(ptr x);
+static ptr s_intern2(ptr x, ptr n);
+static ptr s_strings_to_gensym(ptr pname_str, ptr uname_str);
+static ptr s_intern3(ptr x, ptr n, ptr m);
+static ptr s_delete_file(const char *inpath);
+static ptr s_delete_directory(const char *inpath);
+static ptr s_rename_file(const char *inpath1, const char *inpath2);
+static ptr s_mkdir(const char *inpath, INT mode);
+static ptr s_chmod(const char *inpath, INT mode);
+static ptr s_getmod(const char *inpath, IBOOL followp);
+static ptr s_path_atime(const char *inpath, IBOOL followp);
+static ptr s_path_ctime(const char *inpath, IBOOL followp);
+static ptr s_path_mtime(const char *inpath, IBOOL followp);
+static ptr s_fd_atime(INT fd);
+static ptr s_fd_ctime(INT fd);
+static ptr s_fd_mtime(INT fd);
+static IBOOL s_fd_regularp(INT fd);
+static void s_nanosleep(ptr sec, ptr nsec);
+static ptr s_set_collect_trip_bytes(ptr n);
+static void c_exit(I32 status);
+static ptr s_get_reloc(ptr co);
 #ifdef PTHREADS
-static s_thread_rv_t s_backdoor_thread_start PROTO((void *p));
-static iptr s_backdoor_thread PROTO((ptr p));
-static ptr s_threads PROTO((void));
-static void s_mutex_acquire PROTO((scheme_mutex_t *m));
-static ptr s_mutex_acquire_noblock PROTO((scheme_mutex_t *m));
-static void s_condition_broadcast PROTO((s_thread_cond_t *c));
-static void s_condition_signal PROTO((s_thread_cond_t *c));
+static s_thread_rv_t s_backdoor_thread_start(void *p);
+static iptr s_backdoor_thread(ptr p);
+static ptr s_threads(void);
+static void s_mutex_acquire(scheme_mutex_t *m);
+static ptr s_mutex_acquire_noblock(scheme_mutex_t *m);
+static void s_condition_broadcast(s_thread_cond_t *c);
+static void s_condition_signal(s_thread_cond_t *c);
 #endif
 static void s_byte_copy(ptr src, iptr srcoff, ptr dst, iptr dstoff, iptr cnt);
 static void s_ptr_copy(ptr src, iptr srcoff, ptr dst, iptr dstoff, iptr cnt);
-static ptr s_tlv PROTO((ptr x));
-static void s_stlv PROTO((ptr x, ptr v));
-static void s_test_schlib PROTO((void));
-static void s_breakhere PROTO((ptr x));
-static IBOOL s_interactivep PROTO((void));
-static IBOOL s_same_devicep PROTO((INT fd1, INT fd2));
-static uptr s_malloc PROTO((iptr n));
-static void s_free PROTO((uptr n));
+static ptr s_tlv(ptr x);
+static void s_stlv(ptr x, ptr v);
+static void s_test_schlib(void);
+static void s_breakhere(ptr x);
+static IBOOL s_interactivep(void);
+static IBOOL s_same_devicep(INT fd1, INT fd2);
+static uptr s_malloc(iptr n);
+static void s_free(uptr n);
 #ifdef FEATURE_ICONV
-static ptr s_iconv_open PROTO((const char *tocode, const char *fromcode));
-static void s_iconv_close PROTO((uptr cd));
-static ptr s_iconv_from_string PROTO((uptr cd, ptr in, uptr i, uptr iend, ptr out, uptr o, uptr oend));
-static ptr s_iconv_to_string PROTO((uptr cd, ptr in, uptr i, uptr iend, ptr out, uptr o, uptr oend));
+static ptr s_iconv_open(const char *tocode, const char *fromcode);
+static void s_iconv_close(uptr cd);
+static ptr s_iconv_from_string(uptr cd, ptr in, uptr i, uptr iend, ptr out, uptr o, uptr oend);
+static ptr s_iconv_to_string(uptr cd, ptr in, uptr i, uptr iend, ptr out, uptr o, uptr oend);
 #endif
 #ifdef WIN32
-static ptr s_multibytetowidechar PROTO((unsigned cp, ptr inbv));
-static ptr s_widechartomultibyte PROTO((unsigned cp, ptr inbv));
+static ptr s_multibytetowidechar(unsigned cp, ptr inbv);
+static ptr s_widechartomultibyte(unsigned cp, ptr inbv);
 #endif
-static ptr s_profile_counters PROTO((void));
-static ptr s_profile_release_counters PROTO((void));
+static ptr s_profile_counters(void);
+static ptr s_profile_release_counters(void);
 
 #define require(test,who,msg,arg) if (!(test)) S_error1(who, msg, arg)
 
@@ -139,47 +139,47 @@ ptr S_strerror(INT errnum) {
   return p;
 }
 
-static INT s_errno() {
+static INT s_errno(void) {
   return errno;
 }
 
-static iptr s_addr_in_heap(x) uptr x; {
+static iptr s_addr_in_heap(uptr x) {
   return MaybeSegInfo(addr_get_segment(x)) != NULL;
 }
 
-static iptr s_ptr_in_heap(x) ptr x; {
+static iptr s_ptr_in_heap(ptr x) {
   return MaybeSegInfo(ptr_get_segment(x)) != NULL;
 }
 
-static ptr s_generation(x) ptr x; {
+static ptr s_generation(ptr x) {
   seginfo *si = MaybeSegInfo(ptr_get_segment(x));
   return si == NULL ? Sfalse : FIX(si->generation);
 }
 
-static iptr s_fxmul(x, y) iptr x, y; {
+static iptr s_fxmul(iptr x, iptr y) {
     return x * y;
 }
 
-static iptr s_fxdiv(x, y) iptr x, y; {
+static iptr s_fxdiv(iptr x, iptr y) {
     return x / y;
 }
 
-static ptr s_trunc_rem(x, y) ptr x, y; {
+static ptr s_trunc_rem(ptr x, ptr y) {
   ptr q, r;
   S_trunc_rem(get_thread_context(), x, y, &q, &r);
   return Scons(q, r);
 }
 
-static ptr s_fltofx(x) ptr x; {
+static ptr s_fltofx(ptr x) {
     return FIX((iptr)FLODAT(x));
 }
 
-static ptr s_weak_pairp(p) ptr p; {
+static ptr s_weak_pairp(ptr p) {
   seginfo *si;
   return Spairp(p) && (si = MaybeSegInfo(ptr_get_segment(p))) != NULL && (si->space & ~space_locked) == space_weakpair ? Strue : Sfalse;
 }
 
-static ptr s_ephemeron_cons(car, cdr) ptr car, cdr; {
+static ptr s_ephemeron_cons(ptr car, ptr cdr) {
   ptr p;
 
   tc_mutex_acquire()
@@ -188,12 +188,12 @@ static ptr s_ephemeron_cons(car, cdr) ptr car, cdr; {
   return p;
 }
 
-static ptr s_ephemeron_pairp(p) ptr p; {
+static ptr s_ephemeron_pairp(ptr p) {
   seginfo *si;
   return Spairp(p) && (si = MaybeSegInfo(ptr_get_segment(p))) != NULL && (si->space & ~space_locked) == space_ephemeron ? Strue : Sfalse;
 }
 
-static ptr s_oblist() {
+static ptr s_oblist(void) {
   ptr ls = Snil;
   iptr idx = S_G.oblist_length;
   bucket *b;
@@ -207,15 +207,15 @@ static ptr s_oblist() {
   return ls;
 }
 
-static ptr s_bigoddp(n) ptr n; {
+static ptr s_bigoddp(ptr n) {
     return Sboolean(BIGIT(n, BIGLEN(n) - 1) & 1); /* last bigit */;
 }
 
-static ptr s_float(x) ptr x; {
+static ptr s_float(ptr x) {
     return Sflonum(S_floatify(x));
 }
 
-static ptr s_decode_float(x) ptr x; {
+static ptr s_decode_float(ptr x) {
     require(Sflonump(x),"decode-float","~s is not a float",x);
     return S_decode_float(FLODAT(x));
 }
@@ -627,7 +627,7 @@ static ptr s_system(const char *s) {
 #endif /* WIN32 */
 }
 
-static ptr s_process(s, stderrp) char *s; IBOOL stderrp; {
+static ptr s_process(char *s, IBOOL stderrp) {
     INT ifd = -1, ofd = -1, efd = -1, child = -1;
 
 #ifdef WIN32
@@ -818,7 +818,7 @@ static char *s_getwd() {
 }
 #endif /* GETWD */
 
-static ptr s_set_code_byte(p, n, x) ptr p, n, x; {
+static ptr s_set_code_byte(ptr p, ptr n, ptr x) {
     I8 *a;
 
     a = (I8 *)((uptr)p + UNFIX(n));
@@ -826,7 +826,7 @@ static ptr s_set_code_byte(p, n, x) ptr p, n, x; {
     return Svoid;
 }
 
-static ptr s_set_code_word(p, n, x) ptr p, n, x; {
+static ptr s_set_code_word(ptr p, ptr n, ptr x) {
     I16 *a;
 
     a = (I16 *)((uptr)p + UNFIX(n));
@@ -834,7 +834,7 @@ static ptr s_set_code_word(p, n, x) ptr p, n, x; {
     return Svoid;
 }
 
-static ptr s_set_code_long(p, n, x) ptr p, n, x; {
+static ptr s_set_code_long(ptr p, ptr n, ptr x) {
     I32 *a;
 
     a = (I32 *)((uptr)p + UNFIX(n));
@@ -842,14 +842,14 @@ static ptr s_set_code_long(p, n, x) ptr p, n, x; {
     return Svoid;
 }
 
-static void s_set_code_long2(p, n, h, l) ptr p, n, h, l; {
+static void s_set_code_long2(ptr p, ptr n, ptr h, ptr l) {
     I32 *a;
 
     a = (I32 *)((uptr)p + UNFIX(n));
     *a = (I32)((UNFIX(h) << 16) + UNFIX(l));
 }
 
-static ptr s_set_code_quad(p, n, x) ptr p, n, x; {
+static ptr s_set_code_quad(ptr p, ptr n, ptr x) {
     I64 *a;
 
     a = (I64 *)((uptr)p + UNFIX(n));
@@ -857,7 +857,7 @@ static ptr s_set_code_quad(p, n, x) ptr p, n, x; {
     return Svoid;
 }
 
-static ptr s_set_reloc(p, n, e) ptr p, n, e; {
+static ptr s_set_reloc(ptr p, ptr n, ptr e) {
     iptr *a;
 
     a = (iptr *)(&RELOCIT(CODERELOC(p), UNFIX(n)));
@@ -865,7 +865,7 @@ static ptr s_set_reloc(p, n, e) ptr p, n, e; {
     return e;
 }
 
-static ptr s_flush_instruction_cache() {
+static ptr s_flush_instruction_cache(void) {
     tc_mutex_acquire()
     S_flush_instruction_cache(get_thread_context());
     tc_mutex_release()
@@ -890,13 +890,13 @@ static ptr s_make_code(flags, free, name, arity_mark, n, info, pinfos)
     return co;
 }
 
-static ptr s_make_reloc_table(codeobj, n) ptr codeobj, n; {
+static ptr s_make_reloc_table(ptr codeobj, ptr n) {
     CODERELOC(codeobj) = S_relocation_table(UNFIX(n));
     RELOCCODE(CODERELOC(codeobj)) = codeobj;
     return Svoid;
 }
 
-static ptr s_make_closure(offset, codeobj) ptr offset, codeobj; {
+static ptr s_make_closure(ptr offset, ptr codeobj) {
 
     return S_closure((ptr)((iptr)codeobj + UNFIX(offset)), 0);
 }
@@ -904,7 +904,7 @@ static ptr s_make_closure(offset, codeobj) ptr offset, codeobj; {
 /* the random formula is based on Knuth.  It returns a random fixnum
  * between 0 and n-1.
  */
-static ptr s_fxrandom(p) ptr p; {
+static ptr s_fxrandom(ptr p) {
   ptr tc = get_thread_context();
   uptr t, n = UNFIX(p);
 
@@ -919,7 +919,7 @@ static ptr s_fxrandom(p) ptr p; {
   }
 }
 
-static ptr s_flrandom(x) ptr x; {
+static ptr s_flrandom(ptr x) {
     ptr tc = get_thread_context();
     U32 t1, t2, t3, t4;
 
@@ -935,12 +935,12 @@ static U32 s_random_seed() {
     return RANDOMSEED(tc);
 }
 
-static void s_set_random_seed(x) U32 x; {
+static void s_set_random_seed(U32 x) {
     ptr tc = get_thread_context();
     RANDOMSEED(tc) = x;
 }
 
-static ptr s_intern(x) ptr x; {
+static ptr s_intern(ptr x) {
   require(Sstringp(x),"string->symbol","~s is not a string",x);
 
   return S_intern_sc(&STRIT(x, 0), Sstring_length(x), x);
@@ -1227,7 +1227,7 @@ static int s_getpid(void) {
   return GETPID();
 }
 
-static ptr s_set_collect_trip_bytes(n) ptr n; {
+static ptr s_set_collect_trip_bytes(ptr n) {
     S_G.collect_trip_bytes = Sunsigned_value(n);
     return Svoid;
 }
@@ -1236,32 +1236,17 @@ static void c_exit(UNUSED I32 status) {
     S_abnormal_exit();
 }
 
-#if defined(__STDC__) || defined(USE_ANSI_PROTOTYPES)
-#include <math.h>
-#else /* defined(__STDC__) || defined(USE_ANSI_PROTOTYPES) */
-extern double sin(), cos(), tan(), asin(), acos(), atan(), atan2();
-extern double sinh(), cosh(), tanh(), exp(), log(), pow(), sqrt();
-extern double floor(), ceil(), HYPOT();
-#ifdef ARCHYPERBOLIC
-extern double asinh(), acosh(), atanh();
-#endif /* ARCHHYPERBOLIC */
-#ifdef LOG1P
-extern double log1p();
-#endif /* LOG1P */
-#endif /* defined(__STDC__) || defined(USE_ANSI_PROTOTYPES) */
+static double s_mod(double x, double y) { return fmod(x, y); }
 
-static double s_exp PROTO((double x));
-static double s_exp(x) double x; { return exp(x); }
+static double s_exp(double x) { return exp(x); }
 
-static double s_log PROTO((double x));
-static double s_log(x) double x; { return log(x); }
+static double s_log(double x) { return log(x); }
 
-static double s_pow PROTO((double x, double y));
 #if (machine_type == machine_type_i3fb || machine_type == machine_type_ti3fb)
 #include <ieeefp.h>
 /* freebsd's pow delivers precise results for integer inputs, e.g.,
  * 10.0^21.0, only with * extended-precision (80-bit) floats */
-static double s_pow(x, y) double x, y; {
+static double s_pow(double x, double y) {
   fp_prec_t p;
   p = fpgetprec();
   if (p != FP_PE) {
@@ -1276,72 +1261,52 @@ static double s_pow(x, y) double x, y; {
 #elif defined(MACOSX)
 /* intel macosx delivers precise results for integer inputs, e.g.,
  * 10.0^21.0, only with long double version of pow */
-static double s_pow(x, y) double x, y; { return powl(x, y); }
+static double s_pow(double x, double y) { return powl(x, y); }
 #else /* i3fb/ti3fb */
-static double s_pow(x, y) double x, y; { return pow(x, y); }
+static double s_pow(double x, double y) { return pow(x, y); }
 #endif /* i3fb/ti3fb */
 
-static double s_sqrt PROTO((double x));
-static double s_sqrt(x) double x; { return sqrt(x); }
+static double s_sqrt(double x) { return sqrt(x); }
 
-static double s_sin PROTO((double x));
-static double s_sin(x) double x; { return sin(x); }
+static double s_sin(double x) { return sin(x); }
 
-static double s_cos PROTO((double x));
-static double s_cos(x) double x; { return cos(x); }
+static double s_cos(double x) { return cos(x); }
 
-static double s_tan PROTO((double x));
-static double s_tan(x) double x; { return tan(x); }
+static double s_tan(double x) { return tan(x); }
 
-static double s_asin PROTO((double x));
-static double s_asin(x) double x; { return asin(x); }
+static double s_asin(double x) { return asin(x); }
 
-static double s_acos PROTO((double x));
-static double s_acos(x) double x; { return acos(x); }
+static double s_acos(double x) { return acos(x); }
 
-static double s_atan PROTO((double x));
-static double s_atan(x) double x; { return atan(x); }
+static double s_atan(double x) { return atan(x); }
 
-static double s_atan2 PROTO((double x, double y));
-static double s_atan2(x, y) double x, y; { return atan2(x, y); }
+static double s_atan2(double x, double y) { return atan2(x, y); }
 
-static double s_sinh PROTO((double x));
-static double s_sinh(x) double x; { return sinh(x); }
+static double s_sinh(double x) { return sinh(x); }
 
-static double s_cosh PROTO((double x));
-static double s_cosh(x) double x; { return cosh(x); }
+static double s_cosh(double x) { return cosh(x); }
 
-static double s_tanh PROTO((double x));
-static double s_tanh(x) double x; { return tanh(x); }
+static double s_tanh(double x) { return tanh(x); }
 
-static double s_floor PROTO((double x));
-static double s_floor(x) double x; { return floor(x); }
+static double s_floor(double x) { return floor(x); }
 
-static double s_ceil PROTO((double x));
-static double s_ceil(x) double x; { return ceil(x); }
+static double s_ceil(double x) { return ceil(x); }
 
-static double s_hypot PROTO((double x, double y));
-static double s_hypot(x, y) double x, y; { return HYPOT(x, y); }
+static double s_hypot(double x, double y) { return HYPOT(x, y); }
 
 #ifdef ARCHYPERBOLIC
-static double s_asinh PROTO((double x));
-static double s_asinh(x) double x; { return asinh(x); }
+static double s_asinh(double x) { return asinh(x); }
 
-static double s_acosh PROTO((double x));
-static double s_acosh(x) double x; { return acosh(x); }
+static double s_acosh(double x){ return acosh(x); }
 
-static double s_atanh PROTO((double x));
-static double s_atanh(x) double x; { return atanh(x); }
+static double s_atanh(double x) { return atanh(x); }
 #endif /* ARCHHYPERBOLIC */
 
 #ifdef LOG1P
-static double s_log1p PROTO((double x));
-static double s_log1p(x) double x; { return log1p(x); }
+static double s_log1p(double x) { return log1p(x); }
 #endif /* LOG1P */
 
-static ptr s_getenv PROTO((char *name));
-
-static ptr s_getenv(name) char *name; {
+static ptr s_getenv(char *name) {
 #ifdef WIN32
   char *s = Sgetenv(name);
 #else /* WIN32 */
@@ -1358,8 +1323,7 @@ static ptr s_getenv(name) char *name; {
   }
 }
 
-static void s_putenv PROTO((char *name, char *value));
-static void s_putenv(name, value) char *name, *value; {
+static void s_putenv(char *name, char *value) {
 #ifdef WIN32
   wchar_t* namew;
   wchar_t* valuew;
@@ -1386,7 +1350,7 @@ static void s_putenv(name, value) char *name, *value; {
 #ifdef PTHREADS
 /* backdoor thread is for testing thread creation by Sactivate_thread */
 #define display(s) { const char *S = (s); if (WRITE(1, S, (unsigned int)strlen(S))) {} }
-static s_thread_rv_t s_backdoor_thread_start(p) void *p; {
+static s_thread_rv_t s_backdoor_thread_start(void *p) {
   display("backdoor thread started\n")
   (void) Sactivate_thread();
   display("thread activated\n")
@@ -1401,16 +1365,16 @@ static s_thread_rv_t s_backdoor_thread_start(p) void *p; {
   s_thread_return;
 }
 
-static iptr s_backdoor_thread(p) ptr p; {
+static iptr s_backdoor_thread(ptr p) {
   display("creating thread\n");
   return s_thread_create(s_backdoor_thread_start, (void *)p);
 }
 
-static ptr s_threads() {
+static ptr s_threads(void) {
   return S_threads;
 }
 
-static void s_mutex_acquire(m) scheme_mutex_t *m; {
+static void s_mutex_acquire(scheme_mutex_t *m) {
   ptr tc = get_thread_context();
 
   if (m == &S_tc_mutex) {
@@ -1429,7 +1393,7 @@ static void s_mutex_acquire(m) scheme_mutex_t *m; {
   }
 }
 
-static ptr s_mutex_acquire_noblock(m) scheme_mutex_t *m; {
+static ptr s_mutex_acquire_noblock(scheme_mutex_t *m) {
   return S_mutex_tryacquire(m) == 0 ? Strue : Sfalse;
 }
 
@@ -1485,7 +1449,7 @@ void S_dump_tc(ptr tc) {
   fflush(stdout);
 }
 
-void S_prim5_init() {
+void S_prim5_init(void) {
     if (!S_boot_time) return;
 
 #ifdef PTHREADS
@@ -1631,6 +1595,7 @@ void S_prim5_init() {
     Sforeign_symbol("(cs)dequeue_scheme_signals", (void *)S_dequeue_scheme_signals);
     Sforeign_symbol("(cs)register_scheme_signal", (void *)S_register_scheme_signal);
 
+    Sforeign_symbol("(cs)mod", (void *)s_mod);
     Sforeign_symbol("(cs)exp", (void *)s_exp);
     Sforeign_symbol("(cs)log", (void *)s_log);
     Sforeign_symbol("(cs)pow", (void *)s_pow);
@@ -1692,7 +1657,7 @@ void S_prim5_init() {
     Sforeign_symbol("(cs)s_profile_release_counters", (void *)s_profile_release_counters);
 }
 
-static ptr s_get_reloc(co) ptr co; {
+static ptr s_get_reloc(ptr co) {
   ptr t, ls; uptr a, m, n;
 
   require(Scodep(co),"s_get_reloc","~s is not a code object",co);
@@ -1760,7 +1725,7 @@ static void s_stlv(ptr x, ptr v) {
   if (!(expr)) S_error1("s_test_schlib", "test ~s failed", FIX(test));\
 }
 
-static void s_test_schlib() {
+static void s_test_schlib(void) {
   INT test = 0;
   I32 n1 = 0x73215609;
   I64 n2 = n1 * 37;
@@ -1824,7 +1789,7 @@ static void s_breakhere(UNUSED ptr x) {
   return;
 }
 
-static IBOOL s_interactivep() {
+static IBOOL s_interactivep(void) {
   static INT interactivep = -1;
   if (interactivep == -1) {
 #ifdef WIN32
