@@ -20,7 +20,6 @@
 #include <limits.h>
 #ifdef WIN32
 #include <io.h>
-#include <time.h>
 #else
 #include <sys/time.h>
 #endif
@@ -41,13 +40,13 @@ static heap_state current_state = UNINITIALIZED;
 /* INITIALIZATION SUPPORT */
 
 /* locally defined functions */
-static void main_init PROTO((void));
-static void idiot_checks PROTO((void));
-static INT run_script PROTO((const char *who, const char *scriptfile, INT argc, const char *argv[], IBOOL programp));
+static void main_init(void);
+static void idiot_checks(void);
+static INT run_script(const char *who, const char *scriptfile, INT argc, const char *argv[], IBOOL programp);
 
 extern void scheme_include(void);
   
-static void main_init() {
+static void main_init(void) {
     ptr tc = get_thread_context();
     ptr p;
     INT i;
@@ -151,7 +150,7 @@ static void main_init() {
 
 static ptr fixtest = FIX(-1);
 
-static void idiot_checks() {
+static void idiot_checks(void) {
   IBOOL oops = 0;
 
   if (bytes_per_segment < S_pagesize) {
@@ -332,11 +331,11 @@ static void idiot_checks() {
 /* SUPPORT FOR CALLING INTO SCHEME */
 
 /* locally defined functions */
-static ptr boot_call PROTO((ptr tc, ptr p, INT n));
-static void check_ap PROTO((ptr tc));
+static ptr boot_call(ptr tc, ptr p, INT n);
+static void check_ap(ptr tc);
 
 /* arguments and ac0 set up */
-static ptr boot_call(tc, p, n) ptr tc; ptr p; INT n; {
+static ptr boot_call(ptr tc, ptr p, INT n) {
     AC1(tc) = p;
     CP(tc) = Svoid; /* don't have calling code object */
 
@@ -360,7 +359,7 @@ static ptr boot_call(tc, p, n) ptr tc; ptr p; INT n; {
     return p;
 }
 
-static void check_ap(tc) ptr tc; {
+static void check_ap(ptr tc) {
     if ((uptr)AP(tc) & (byte_alignment - 1)) {
         (void) fprintf(stderr, "ap is not double word aligned\n");
         S_abnormal_exit();
@@ -371,13 +370,13 @@ static void check_ap(tc) ptr tc; {
     }
 }
 
-void S_generic_invoke(tc, code) ptr tc; ptr code; {
+void S_generic_invoke(ptr tc, ptr code) {
 #if defined(PPCAIX)
     struct {caddr_t entry, toc, static_link;} hdr;
     hdr.entry = (caddr_t)&CODEIT(code,0);
     hdr.toc = (caddr_t)0;
     hdr.static_link = (caddr_t)0;
-    (*((void (*) PROTO((ptr)))(void *)&hdr))(tc);
+    (*((void (*)(ptr))(void *)&hdr))(tc);
 #elif defined(PPCNT)
   /* under NT, function headers contain no static link */
     struct {I32 entry, toc;} hdr;
@@ -398,7 +397,7 @@ void S_generic_invoke(tc, code) ptr tc; ptr code; {
     p(tc);
 #elif defined(WIN32) && !defined(__MINGW32__)
     __try {
-      (*((void (*) PROTO((ptr)))(void *)&CODEIT(code,0)))(tc);
+      (*((void (*)(ptr))(void *)&CODEIT(code,0)))(tc);
     }
     __except(GetExceptionCode() == EXCEPTION_ACCESS_VIOLATION ?
              EXCEPTION_EXECUTE_HANDLER : EXCEPTION_CONTINUE_SEARCH)
@@ -409,7 +408,7 @@ void S_generic_invoke(tc, code) ptr tc; ptr code; {
             S_error_reset("invalid memory reference");
     }
 #else
-    (*((void (*) PROTO((ptr)))(void *)&CODEIT(code,0)))(tc);
+    (*((void (*)(ptr))(void *)&CODEIT(code,0)))(tc);
 #endif
 }
 
@@ -417,9 +416,9 @@ void S_generic_invoke(tc, code) ptr tc; ptr code; {
 /* MISCELLANEOUS HELPERS */
 
 /* locally defined functions */
-static IBOOL next_path PROTO((char *path, const char *name, const char *ext, const char **sp, const char **dsp));
-static const char *path_last PROTO((const char *path));
-static char *get_defaultheapdirs PROTO((void));
+static IBOOL next_path(char *path, const char *name, const char *ext, const char **sp, const char **dsp);
+static const char *path_last(const char *path);
+static char *get_defaultheapdirs(void);
 
 static const char *path_last(p) const char *p; {
   const char *s;
@@ -473,7 +472,8 @@ static char *get_defaultheapdirs() {
  * the search path.  path should be a pointer to an unoccupied buffer
  * PATH_MAX characters long.  either or both of sp/dsp may be empty,
  * but neither may be null, i.e., (char *)0. */
-static IBOOL next_path(path, name, ext, sp, dsp) char *path; const char *name, *ext, **sp, **dsp; {
+static IBOOL next_path(char *path, const char *name, const char *ext,
+                       const char **sp, const char **dsp) {
   char *p;
   const char *s, *t;
 
@@ -570,14 +570,14 @@ typedef struct {
 static boot_desc bd[MAX_BOOT_FILES];
 
 /* locally defined functions */
-static char get_u8 PROTO((INT fd));
-static uptr get_uptr PROTO((INT fd, uptr *pn));
-static INT get_string PROTO((INT fd, char *s, iptr max, INT *c));
-static IBOOL find_boot PROTO((const char *name, const char *ext, int fd, IBOOL errorp));
-static void load PROTO((ptr tc, iptr n, IBOOL base));
-static void check_boot_file_state PROTO((const char *who));
+static char get_u8(INT fd);
+static uptr get_uptr(INT fd, uptr *pn);
+static INT get_string(INT fd, char *s, iptr max, INT *c);
+static IBOOL find_boot(const char *name, const char *ext, int fd, IBOOL errorp);
+static void load(ptr tc, iptr n, IBOOL base);
+static void check_boot_file_state(const char *who);
 
-static IBOOL find_boot(name, ext, fd, errorp) const char *name, *ext; int fd; IBOOL errorp; {
+static IBOOL find_boot(const char *name, const char *ext, int fd, IBOOL errorp) {
   char pathbuf[PATH_MAX], buf[PATH_MAX];
   uptr n = 0;
   INT c;
@@ -823,7 +823,7 @@ static uptr get_uptr(INT fd, uptr *pn) {
   return 0;
 }
 
-static INT get_string(fd, s, max, c) INT fd; char *s; iptr max; INT *c; {
+static INT get_string(INT fd, char *s, iptr max, INT *c) {
   while (max-- > 0) {
     if (*c < 0) return -1;
     if (*c == ' ' || *c == ')') {
@@ -850,7 +850,7 @@ static int set_load_binary(iptr n) {
   return 0;
 }
 
-static void load(tc, n, base) ptr tc; iptr n; IBOOL base; {
+static void load(ptr tc, iptr n, IBOOL base) {
   ptr x; iptr i;
 
   if (base) {
@@ -932,7 +932,7 @@ const char *Skernel_version(void) {
   return VERSION;
 }
 
-extern void Sset_verbose(v) INT v; {
+extern void Sset_verbose(INT v) {
   verbose = v;
 }
 
@@ -940,6 +940,27 @@ extern void Sretain_static_relocation(void) {
   S_G.retain_static_relocation = 1;
 }
 
+#if defined(CHECK_FOR_ROSETTA)
+#include <sys/sysctl.h>
+int is_rosetta = 0;
+static void init_rosetta_check(void) {
+  int val = 0;
+  size_t size = sizeof(val);
+  if (sysctlbyname("sysctl.proc_translated", &val, &size, NULL, 0) != 0) {
+    if (errno == ENOENT) {
+         is_rosetta = 0;
+    } else {
+      perror("checking to see if running under Rosetta");
+      // if for some reason we can't tell whether we are running under Rosetta or not,
+      // default to the safer choice.  It doesn't impact correctness to do the Rosetta
+      // workarounds when they are not needed.
+      is_rosetta = 1;
+    }
+  }
+  is_rosetta = val;
+}
+#endif
+
 #ifdef ITEST
 #include "itest.c"
 #endif
@@ -948,7 +969,7 @@ static void default_abnormal_exit(void) {
   exit(1);
 }
 
-extern void Sscheme_init(abnormal_exit) void (*abnormal_exit) PROTO((void)); {
+extern void Sscheme_init(void (*abnormal_exit)(void)) {
   S_abnormal_exit_proc = abnormal_exit ? abnormal_exit : default_abnormal_exit;
   S_errors_to_console = 1;
 
@@ -956,7 +977,10 @@ extern void Sscheme_init(abnormal_exit) void (*abnormal_exit) PROTO((void)); {
   S_pagesize = GETPAGESIZE();
 
   idiot_checks();
-
+#if defined(CHECK_FOR_ROSETTA)
+  init_rosetta_check();
+#endif
+  
   switch (current_state) {
     case RUNNING:
       fprintf(stderr, "error (Sscheme_init): call Sscheme_deinit first to terminate\n");
@@ -1021,12 +1045,12 @@ static void check_boot_file_state(const char *who) {
   }
 }
 
-extern void Sregister_boot_file(name) const char *name; {
+extern void Sregister_boot_file(const char *name) {
   check_boot_file_state("Sregister_boot_file");
   find_boot(name, "", -1, 1);
 }
 
-extern void Sregister_boot_file_fd(name, fd) const char *name; int fd; {
+extern void Sregister_boot_file_fd(const char *name, int fd) {
   check_boot_file_state("Sregister_boot_file_fd");
   find_boot(name, "", fd, 1);
 }
@@ -1036,7 +1060,7 @@ extern void Sregister_heap_file(UNUSED const char *path) {
   S_abnormal_exit();
 }
 
-extern void Sbuild_heap(kernel, custom_init) const char *kernel; void (*custom_init) PROTO((void)); {
+extern void Sbuild_heap(const char *kernel, void (*custom_init)(void)) {
   ptr tc = Svoid; /* initialize to make gcc happy */
   ptr p;
 
@@ -1135,14 +1159,14 @@ extern void Sbuild_heap(kernel, custom_init) const char *kernel; void (*custom_i
   S_errors_to_console = 0;
 }
 
-extern void Senable_expeditor(history_file) const char *history_file; {
+extern void Senable_expeditor(const char *history_file) {
   Scall1(S_symbol_value(Sstring_to_symbol("$enable-expeditor")), Strue);
   if (history_file != (const char *)0)
     Scall1(S_symbol_value(Sstring_to_symbol("$expeditor-history-file")),
            Sstring_utf8(history_file, -1));
 }
 
-extern INT Sscheme_start(argc, argv) INT argc; const char *argv[]; {
+extern INT Sscheme_start(INT argc, const char *argv[]) {
   ptr tc = get_thread_context();
   ptr arglist, p; INT i;
 
@@ -1212,11 +1236,11 @@ static INT run_script(const char *who, const char *scriptfile, INT argc, const c
   return p == Svoid ? 0 : 1;
 }
 
-extern INT Sscheme_script(scriptfile, argc, argv) const char *scriptfile; INT argc; const char *argv[]; {
+extern INT Sscheme_script(const char *scriptfile, INT argc, const char *argv[]) {
   return run_script("Sscheme_script", scriptfile, argc, argv, 0);
 }
 
-extern INT Sscheme_program(programfile, argc, argv) const char *programfile; INT argc; const char *argv[]; {
+extern INT Sscheme_program(const char *programfile, INT argc, const char *argv[]) {
   return run_script("Sscheme_program", programfile, argc, argv, 1);
 }
 
@@ -1225,7 +1249,7 @@ extern void Ssave_heap(UNUSED const char *path, UNUSED INT level) {
   S_abnormal_exit();
 }
 
-extern void Sscheme_deinit() {
+extern void Sscheme_deinit(void) {
   ptr p, tc = get_thread_context();
 
   switch (current_state) {
